@@ -5,7 +5,7 @@ use 5.010_001;
 
 use parent qw(Exporter);
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 our @EXPORT = qw(CTX);
 sub CTX { $Cinnamon::Context::CTX };
@@ -60,7 +60,7 @@ Cinnamon - A minimalistic deploy tool
 
   # Tasks
   task update => sub {
-      my ($host, @args) = @_;
+      my ($host) = @_;
       my $deploy_to = get('deploy_to');
       my $branch = 'origin/' . get('branch');
 
@@ -73,14 +73,14 @@ Cinnamon - A minimalistic deploy tool
       } $host;
   };
   task restart => sub {
-    my ($host, @args) = @_;
+    my ($host) = @_;
     # ...
   };
 
   # Nest tasks
   task server => {
       setup => sub {
-          my ($host, @args) = @_;
+          my ($host) = @_;
           # ...
       },
   };
@@ -140,10 +140,8 @@ parameters by get DSL.
 
 =head3 task ( I<$taskname: Str> => (I<\%tasks: Hash[String => CODE]> | I<$sub: CODE>) )
 
-=over 4
-
   task update => sub {
-      my ($host, @args) = @_;
+      my ($host) = @_;
       my $hoge = get 'hoge'; # parameter set in global or role parameter
       # ...
   };
@@ -151,11 +149,11 @@ parameters by get DSL.
   # you can nest tasks
   task server => {
       start => sub {
-        my ($host, @args) = @_;
+        my ($host) = @_;
         # ...
       },
       stop => sub {
-        my ($host, @args) = @_;
+        my ($host) = @_;
         # ...
       },
   };
@@ -171,16 +169,6 @@ The arguments which are passed into the CODEs are:
 The host name where the task is executed. Which is one of the hosts
 you set by C<role> command.
 
-=item * I<@args>
-
-Command line argument which is passed by user.
-
-  $ cinammon production update foo bar baz
-
-In case above, C<@args> contains C<('foo', 'bar', 'baz')>.
-
-=back
-
 =back
 
 =head2 Utilities
